## Removing grub timeout during bootup.
To remove the timeout grub shows during bootup, edit ```/etc/default/grub``` by modfying the ```GRUB_TIMEOUT``` value. Then run ```grub-mkconfig``` as sudo to update your grub configuration. Check out [this](https://bbs.archlinux.org/viewtopic.php?id=169948) post if something goes wrong.


## Getting xserver up.
```bash
# Graphics driver.
yaourt -S xf86-video-vesa 

# Xorg
yaourt -S xorg-server 

# So you can run startx.
yaourt -S xorg-xinit 

# Xorg's default tiling manager
yaourt -S xorg-twm

# Xterm, so we actually get something on screen.
yaourt -S xterm

# Copy a sane default of .xinitrc
cp /etc/X11/xinit/xinitrc ~/.xinitrc

# Get an x display session up.
startx
```

## Auto login and startx
To do auto login [Arch Wiki](https://wiki.archlinux.org/index.php/Automatic_login_to_virtual_console):
```bash
# /etc/systemd/system/getty@tty1.service.d/override.conf

[Service]
ExecStart=
ExecStart=-/usr/bin/agetty --autologin username --noclear %I 38400 linux
```

To do auto startx [Arch Wiki](https://wiki.archlinux.org/index.php/Xinitrc#Autostart_X_at_login):
```bash
#~/.zshrc

[[ -z $DISPLAY && $XDG_VTNR -eq 1 ]] && exec startx
```

## Tiling manager (I3-gaps).
```bash
#I3-gaps since it is a very awesome fork of i3 that adds a ton of functionality.
yaourt -S i3-gaps-git

# For a wallpaper.
yaourt -S feh imagemagick librsvg

# Replace TWM relevant command with just exec i3.
vim ~/.xinitrc

# And if you need to modify anything i3, like the keys:
# Mod1 -> ALT key
# Mod4 -> Windows key (This does not work with virtualbox!)
vim ~/.config/i3/config
```

Some quick additions to take advantage of gaps.
```bash
# Inside ~/.config/i3/config

for_window [class="^.*"] border pixel 2
gaps inner 12
smart_borders no_gaps

# Wallpaper
exec feh --bg-fill ~/wallpapers/wallpaper.jpg
```

## Resizing in virtualbox.
```bash 
# Get virtualbox guest additions.
yaourt -S virtualbox-guest-utils

# Load the virtualbox kernel modules upon bootup.
# Add vboxguest, vboxsf, and vboxvideo on new lines.
vim /etc/modules-load.d/virtualbox.conf

# Add /usr/bin/VBoxClient-all to you .xinitrc before calling I3.
vim ~/.xinitrc
```

## Styling
```bash
# First install xorg-xrdb for reading the xresources file.
yaourt -S xorg-xrdb

# Add the powerline font.
yaourt -S powerline-fonts-git

# And powerline itself.
yaourt -S python2-powerline-git

# Add some goodies to our Xresources.
cat <<EOF > ~/.Xresources
URxvt.background: Black
URxvt.foreground: White
URxvt.scrollbar: false
URxvt.font xft:Sauce Code Powerline:size=9

Xft.dpi: 109
Xft.antialias: true
Xft.rgba: rgba
Xft.hinting: true
Xft.hintstyle: hintfull
EOF

# Add powerline.zsh to our zshrc.
cat ". /usr/share/zsh/site-contrib/powerline.zsh" >> ~/.zshrc
```

## Driver for wifi OurLink AC600
[Forum](http://www.linuxquestions.org/questions/linux-networking-3/ourlink-ac600-wireless-usb-adapter-not-working-on-newly-installed-ubuntu-gnome-16-10-a-4175597852/) says to use [this](https://github.com/Grawp/rtl8812au_rtl8821au) but it [doesn't](https://github.com/Grawp/rtl8812au_rtl8821au/pull/46) compile with newest kernel. Instead, [this](https://aur.archlinux.org/packages/rtl8812au-v5-dkms-git/) does and seems to work fine.

## Vmware Guest
The [Wiki](https://wiki.archlinux.org/index.php/VMware/Installing_Arch_as_a_guest) has a decent bit of good info, but if using Antergos then a lot is done for you. Networking and auto window resizing works, but clipboard is still iffy. For that, you must install [some](https://www.reddit.com/r/archlinux/comments/2ipvmw/vmware_copypaste_not_working_openvmtools/) packages via ```yaourt -S gtkmm libxtst``` and restart the machine.
